@@ -1,7 +1,7 @@
 /*
  * The main header file for SIP.
  *
- * Copyright (c) 2018 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2016 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -27,8 +27,8 @@
 /*
  * Define the SIP version number.
  */
-#define SIP_VERSION         0x04130c
-#define SIP_VERSION_STR     "4.19.12"
+#define SIP_VERSION         0x041303
+#define SIP_VERSION_STR     "4.19.3"
 
 
 #ifdef TRUE
@@ -88,7 +88,6 @@
 #define MOD_SUPER_INIT_YES      0x0100  /* Call super().__init__(). */
 #define MOD_SUPER_INIT_UNDEF    0x0000  /* Calling super().__init__() is undefined. */
 #define MOD_SUPER_INIT_MASK     0x0180  /* The mask for the above flags. */
-#define MOD_SETTING_IMPORTS     0x0200  /* Imports are being set. */
 
 #define hasDelayedDtors(m)  ((m)->modflags & MOD_HAS_DELAYED_DTORS)
 #define setHasDelayedDtors(m)   ((m)->modflags |= MOD_HAS_DELAYED_DTORS)
@@ -109,9 +108,6 @@
 #define setCallSuperInitYes(m)  ((m)->modflags = ((m)->modflags & ~MOD_SUPER_INIT_MASK) | MOD_SUPER_INIT_YES)
 #define isCallSuperInitYes(m)   (((m)->modflags & MOD_SUPER_INIT_MASK) == MOD_SUPER_INIT_YES)
 #define isCallSuperInitUndefined(m) (((m)->modflags & MOD_SUPER_INIT_MASK) == MOD_SUPER_INIT_UNDEF)
-#define settingImports(m)   ((m)->modflags & MOD_SETTING_IMPORTS)
-#define setSettingImports(m)    ((m)->modflags |= MOD_SETTING_IMPORTS)
-#define resetSettingImports(m)  ((m)->modflags &= ~MOD_SETTING_IMPORTS)
 
 
 /* Handle section flags. */
@@ -294,7 +290,6 @@
 #define ENUM_WAS_PROT       0x00000100  /* It was defined as protected. */
 #define ENUM_NO_SCOPE       0x00000200  /* Omit the member scopes. */
 #define ENUM_NEEDS_ENUM     0x00000400  /* The module needs it. */
-#define ENUM_SCOPED         0x00000800  /* A C++0x11 scoped enum. */
 
 #define isProtectedEnum(e)  ((e)->enumflags & SECT_IS_PROT)
 #define setIsProtectedEnum(e)   ((e)->enumflags |= SECT_IS_PROT)
@@ -307,8 +302,6 @@
 #define setIsNoScope(e)     ((e)->enumflags |= ENUM_NO_SCOPE)
 #define needsEnum(e)        ((e)->enumflags & ENUM_NEEDS_ENUM)
 #define setNeedsEnum(e)     ((e)->enumflags |= ENUM_NEEDS_ENUM)
-#define isScopedEnum(e)     ((e)->enumflags & ENUM_SCOPED)
-#define setIsScopedEnum(e)  ((e)->enumflags |= ENUM_SCOPED)
 
 
 /* Handle hierarchy flags. */
@@ -543,14 +536,6 @@ typedef enum {
 } Format;
 
 
-/* Docstring signature positioning. */
-typedef enum {
-    discarded,
-    prepended,
-    appended
-} Signature;
-
-
 /* Levels of keyword argument support. */
 typedef enum {
     NoKwArgs = 0,
@@ -853,7 +838,6 @@ typedef struct {
     int nrderefs;                       /* Nr. of dereferences. */
     int derefs[MAX_NR_DEREFS];          /* The const for each dereference. */
     valueDef *defval;                   /* The default value. */
-    int scopes_stripped;                /* Nr. of scopes to be stripped. */
     int key;                            /* The optional /KeepReference/ key. */
     struct _typedefDef *original_type;  /* The original type if typedef'd. */
     union {
@@ -925,26 +909,17 @@ typedef struct _typeHintNodeDef {
 } typeHintNodeDef;
 
 
-/* An explicit docstring. */
-typedef struct _docstringDef {
-    Signature signature;                /* How the signature should be positioned. */
-    char *text;                         /* The text of the docstring. */
-} docstringDef;
-
-
 /* A module definition. */
 typedef struct _moduleDef {
     nameDef *fullname;                  /* The full module name. */
     const char *name;                   /* The module base name. */
-    docstringDef *docstring;            /* The docstring. */
     apiVersionRangeDef *api_versions;   /* The defined APIs. */
     apiVersionRangeDef *api_ranges;     /* The list of API version ranges. */
     int modflags;                       /* The module flags. */
     KwArgs kwargs;                      /* The style of keyword argument support. */
     struct _memberDef *othfuncs;        /* List of other functions. */
     struct _overDef *overs;             /* Global overloads. */
-    Format defdocstringfmt;             /* The default docstring format. */
-    Signature defdocstringsig;          /* The default docstring signature. */
+    Format defdocstring;                /* The default docstring format. */
     argType encoding;                   /* The default string encoding. */
     nameDef *defmetatype;               /* The optional default meta-type. */
     nameDef *defsupertype;              /* The optional default super-type. */
@@ -957,6 +932,7 @@ typedef struct _moduleDef {
     codeBlockList *postinitcode;        /* Post-initialisation code. */
     codeBlockList *unitcode;            /* Compilation unit code. */
     codeBlockList *unitpostinccode;     /* Compilation unit post-include code. */
+    codeBlockList *docstring;           /* The docstring. */
     codeBlockList *typehintcode;        /* Type hint code. */
     const char *virt_error_handler;     /* The virtual error handler. */
     int parts;                          /* The number of parts generated. */
@@ -1102,9 +1078,9 @@ typedef struct _varDef {
 /* A property definition. */
 typedef struct _propertyDef {
     nameDef *name;                      /* The property name. */
-    docstringDef *docstring;            /* The docstring. */
     const char *get;                    /* The name of the getter method. */
     const char *set;                    /* The name of the setter method. */
+    codeBlockList *docstring;           /* The docstring. */
     platformDef *platforms;             /* The platforms. */
     struct _propertyDef *next;          /* Next in the list. */
 } propertyDef;
@@ -1114,7 +1090,6 @@ typedef struct _propertyDef {
 typedef struct _overDef {
     sourceLocation sloc;                /* The source location. */
     char *cppname;                      /* The C++ name. */
-    docstringDef *docstring;            /* The docstring. */
     int overflags;                      /* The overload flags. */
     int no_typehint;                    /* The type hint will be suppressed. */
     int pyqt_signal_hack;               /* The PyQt signal hack. */
@@ -1138,7 +1113,6 @@ typedef struct _overDef {
 
 /* An overloaded constructor definition. */
 typedef struct _ctorDef {
-    docstringDef *docstring;            /* The docstring. */
     int ctorflags;                      /* The ctor flags. */
     int no_typehint;                    /* The type hint will be suppressed. */
     KwArgs kwargs;                      /* The keyword argument support. */
@@ -1195,6 +1169,7 @@ typedef struct _memberDef {
     int membernr;                       /* The index in the method table. */
     slotType slot;                      /* The slot type. */
     moduleDef *module;                  /* The owning module. */
+    codeBlockList *docstring;           /* The overloads docstrings. */
     struct _ifaceFileDef *ns_scope;     /* The scope if it has been moved. */
     struct _memberDef *next;            /* Next in the list. */
 } memberDef;
@@ -1233,7 +1208,6 @@ typedef struct _mroDef {
 
 /* A class definition. */
 typedef struct _classDef {
-    docstringDef *docstring;            /* The class docstring. */
     unsigned classflags;                /* The class flags. */
     unsigned classflags2;               /* The class flags, part 2. */
     int pyqt_flags;                     /* The PyQt specific flags. */
@@ -1261,6 +1235,7 @@ typedef struct _classDef {
     codeBlockList *cppcode;             /* Class C++ code. */
     codeBlockList *convtosubcode;       /* Convert to sub C++ code. */
     struct _classDef *subbase;          /* Sub-class base class. */
+    codeBlockList *docstring;           /* Class and ctor docstrings. */
     codeBlockList *instancecode;        /* Create instance code. */
     codeBlockList *convtocode;          /* Convert to C++ code. */
     codeBlockList *convfromcode;        /* Convert from C++ code. */
@@ -1376,7 +1351,7 @@ void parserEOF(const char *,parserContext *);
 void transform(sipSpec *, int);
 void generateCode(sipSpec *, char *, char *, char *, const char *, int, int,
         int, int, stringList *needed_qualifiers, stringList *, const char *,
-        int, int, const char *);
+        int, int);
 void generateExtracts(sipSpec *pt, const stringList *extracts);
 void addExtractPart(sipSpec *pt, const char *id, int order, codeBlock *part);
 void generateAPI(sipSpec *pt, moduleDef *mod, const char *apiFile);
@@ -1508,27 +1483,21 @@ typedef struct _autoPyNameCfg {
 typedef struct _compModuleCfg {
     int token;
     const char *name;
-    docstringDef *docstring;
+    codeBlock *docstring;
 } compModuleCfg;
 
 /* %ConsolidatedModule */
 typedef struct _consModuleCfg {
     int token;
     const char *name;
-    docstringDef *docstring;
+    codeBlock *docstring;
 } consModuleCfg;
 
 /* %DefaultDocstringFormat */
-typedef struct _defDocstringFmtCfg {
+typedef struct _defDocstringCfg {
     int token;
     const char *name;
-} defDocstringFmtCfg;
-
-/* %DefaultDocstringSignature */
-typedef struct _defDocstringSigCfg {
-    int token;
-    const char *name;
-} defDocstringSigCfg;
+} defDocstringCfg;
 
 /* %DefaultEncoding */
 typedef struct _defEncodingCfg {
@@ -1552,7 +1521,6 @@ typedef struct _defSupertypeCfg {
 typedef struct _docstringCfg {
     int token;
     Format format;
-    Signature signature;
 } docstringCfg;
 
 /* %Exception */
@@ -1614,7 +1582,7 @@ typedef struct _moduleCfg {
     int all_raise_py_exc;
     int call_super_init;
     const char *def_error_handler;
-    docstringDef *docstring;
+    codeBlock *docstring;
 } moduleCfg;
 
 /* %Plugin */
@@ -1629,7 +1597,7 @@ typedef struct _propertyCfg {
     const char *get;
     const char *name;
     const char *set;
-    docstringDef *docstring;
+    codeBlock *docstring;
 } propertyCfg;
 
 /* Variable sub-directives. */
